*------------------------------------------------------------------------------
*- Version....: Sage Pro ERP 7.50.00
*- File Name..: $Workfile: OBJDRILL.PRG $
*- VCS Level..: $Revision: 1 $
*- Last Update: $Date: 12/21/06 12:25p $
*------------------------------------------------------------------------------
*- Notice.....: Copyright (c) 1985-1998 SBT Corporation. All rights reserved.
*------------------------------------------------------------------------------
*- App ID.....: Tools
*- App Name...: Developer tools
*------------------------------------------------------------------------------
*- Synopsis...: Tool to drill down and select an object that the mouse
*-				is positioned over.
*-
*-				Uses the VFP shorcut keys of Ctrl-Home to get to first object.
*-				Then finds the level the object over the mouse is by counting
*-				its parent hierarchy level and then does a MOUSE CLICK RIGHT
*-				and a KEYBOARD "E" to get to that level and then a MOUSE CLICK
*-				to select the object.
*-
*-				The above logic is used since at design time VFP does not give
*-				a direct way of selecting a object (SetFocus method 
*-				will not work).
*-
*-				Known issues:
*-					1. Does not select page (instead selects pageframe)
*-					2. Does not select column in grid
*-					3. Sometimes does not select the correct object.
*-					4. Due to keyboarding causes screen to flicker.
*-					5. If the property sheet is placed where the mouse is
*-						it causes some of the key strokes to get to the property
*-						sheet. So if the property sheet left and top are less
*-						than the mouse position left and top the property sheet
*-						is moved 5 columns to the right of the mouse
*------------------------------------------------------------------------------
*- Called By..: Hot key while in class or form designer
*------------------------------------------------------------------------------
*- Calls......: None
*------------------------------------------------------------------------------
*- Example....:	ON KEY LABEL F7 DO tools\objdrill
*------------------------------------------------------------------------------
LOCAL ARRAY	la_MouseObj[1], ;
			la_Parents[1]

LOCAL	ll_Countinue, ;
		ln_TotalLevels, ;
		ln_CurrentLevel, ;
		ln_StartLevel, ;
		ln_DownArrow, ;
		lc_BaseClass

ll_Continue	= .t.

STORE 0 TO	ln_TotalLevels, ;
			ln_CurrentLevel, ;
			ln_StartLevel, ;
			ln_DownArrow

lc_BaseClass	= SPACE(0)			

*-- Get the object positioned over the mouse
= AMOUSEOBJ(la_MouseObj, 1)

IF TYPE("la_MouseObj[1].BaseClass") <> "C"
	MESSAGEBOX("Mouse not positioned over an object.")
	ll_Continue	= .f.
ENDIF

IF ll_Continue

	IF UPPER(la_MouseObj[1].BaseClass)	== "FORM"
		MESSAGEBOX("Mouse not positioned over an object on the form.")
		ll_Continue	= .f.
	ENDIF
	
ENDIF

IF ll_Continue

	IF UPPER(la_MouseObj[1].Parent.BaseClass)	== "FORM"
		*-- Object not inside a container.
		*-- Give mouse click to select it.
		MOUSE CLICK
		ll_Continue	= .f.
	ENDIF

ENDIF

IF ll_Continue

	ln_TotalLevels	= l_BuildParent(la_MouseObj[1], @la_Parents)

	IF NOT WEXIST("Properties")
		ACTIVATE WINDOW Properties
	ENDIF

	IF MROW() >= WLROW("Properties") AND ;
		MCOL() >= WLCOL("Properties")
		*-- If the properties window is placed where the mouse was clicked
		*-- the mouse clicks & key strokes get sent to the property sheet
		*-- So the property sheet is moved to the right of the mouse
		MOVE WINDOW Properties TO WLROW("Properties"), MCOL() + 5
	ENDIF
	
	*-- Select top object.
	KEYBOARD "{CTRL-HOME}" PLAIN CLEAR

	*-- Select the outer container object
	MOUSE CLICK

	IF ln_TotalLevels > 0
		*-- Now drill down to object over mouse

		*-- Since we have selected container we can
		*-- skip 2 levels.
		ln_StartLevel	= 2
		
		*-- Find out starting level by skipping a level for
		*-- formset, grid, pageframe etc.
		FOR ln_CurrentLevel	= 1 TO ln_TotalLevels
		
			lc_BaseClass	= UPPER(la_Parents[ln_CurrentLevel].BaseClass)
			
			*-- We need to skip a level for the classes below
			IF INLIST(lc_BaseClass, "FORMSET", "PAGEFRAME", "GRID")
				ln_StartLevel	= ln_StartLevel + 1
			ENDIF

		NEXT	

		*-- Mimic RightClick and 3 downarrows and Enter (to select Edit)
		FOR ln_CurrentLevel	= ln_StartLevel TO ln_TotalLevels
			MOUSE CLICK RIGHT

			FOR ln_DownArrow	= 1 TO 3
				KEYBOARD "{DNARROW}" PLAIN
			NEXT

			KEYBOARD "{Enter}" PLAIN
		NEXT

	ENDIF

	*-- Finally select the object
	MOUSE CLICK
ENDIF

RETURN

FUNCTION l_BuildParent

LPARAMETERS po_Object, ;
			ra_Parents

LOCAL	lo_Object, ;
		ln_Row, ;
		ll_ArrayPassed

lo_Object	= po_Object
ln_Row		= 0

IF TYPE("ra_Parents[1]") <> "U"
	ll_ArrayPassed	= .t.
ELSE
	ll_ArrayPassed	= .f.
ENDIF

DO WHILE TYPE("lo_Object.Parent.BaseClass") = "C"
	lo_Object	= lo_Object.Parent
	
	ln_Row	= ln_Row + 1		

	IF ll_ArrayPassed
		DECLARE ra_Parents[ln_Row, MAX(1, ALEN(ra_Parents, 2))]
		ra_Parents[ln_Row, 1] = lo_Object
	ENDIF

ENDDO

RETURN ln_Row
*------------------------------------------------------------------------------
*- End Procedure..: $Workfile: OBJDRILL.PRG $
*------------------------------------------------------------------------------
