*------------------------------------------------------------------------------
*- Version....: Sage Pro ERP 7.50.00
*- File Name..: $Workfile: PRORUNMENU.PRG $
*- VCS Level..: $Revision: 1 $
*- Last Update: $Date: 12/21/06 12:25p $
*------------------------------------------------------------------------------
*- Copyright (C) 2008 Sage Accpac International, Inc.  All Rights Reserved.
*------------------------------------------------------------------------------
*- Description: Calls specified menu option using menu id
*------------------------------------------------------------------------------
*- Synopsis...: To launch a specific form/report using its menu id. This tool
*-              can be used only after loading any Pro application using 
*-              "tools\ProLoadApp.prg".
*------------------------------------------------------------------------------
*- Passed:
*- Parameters.: pc_MenuID,  MenuID for the calling form
*-
*------------------------------------------------------------------------------
*- Example:      Calling AP's Vendors maintain form
*-
*-   Step 1: DO Tools\ProLoadApp WITH "AP", "99", .t.
*-   Step 2: DO Tools\ProRunMenu WITH "M00001    "
*-
*------------------------------------------------------------------------------
LPARAMETERS pc_MenuId

*-- Include global constants
#include global.h
#include events.h
#include windows.h

LOCAL ll_Return, ;
      lc_MenuID, ;
      lc_MenuScript, ;
      ll_DetlSmry, ;
      ln_OpnSymmenu, ;
      lc_PrgFileName, ;
      lc_ErrMsg, ;
      lc_Applid, ;
      lc_CompID, ;
      lc_Descrip 

*-- Activate menu
STORE 0 TO lb_tbbrow, ;
           lb_tbstat, ;
           lb_tbtech, ;
           lb_tbuser, ;
           lb_tbdebug, ;
           lb_tbcalc, ;
           lb_tbmesg, ;
           lb_tbexit, ;
           lb_tbhelp

*-- Initialize variable
lc_ErrMsg  = ""
lc_Descrip = ""

*-- Veryfy gloabl objects
IF NOT (TYPE("go_Pro") == "O" AND TYPE("go_sql") == "O" ;
            AND TYPE("go_cop") == "O") 

  MESSAGEBOX("Execute the tool 'PROLOADAPP.PRG' to load an application" + ;
             CHR(10) + CHR(13) + ;
             "before running this program.", 64)

  RETURN TO MASTER 
ELSE

 IF TYPE("gc_Applid") == "C" AND NOT EMPTY(gc_Applid)
   *-- Reset the pro default application
   go_pro.sc_Applid = gc_Applid
 ENDIF

ENDIF

IF TYPE("pc_MenuID") == "C" AND NOT EMPTY(pc_MenuID)
  ll_Return = .t.
  lc_MenuID = pc_MenuID
ELSE
  *-- Blank menu id not allowed
  lc_Msg = "Parameters: " + CHR(10) + CHR(13) + ;
           "pc_Menuid, Menu ID (Required)"

  MESSAGEBOX(lc_Msg, 16)

  RETURN TO MASTER
ENDIF

IF ll_Return
  *-- Open Menu master table
  ln_OpnSymmenu = g_opnfl(gc_idrvdbf + "symmenu", "a_Symmenu", .f., .f., "mnuid")

  IF go_SQL.cmpA_Symmenu.m_Seek(lc_MenuId, "mnuid")
    lc_MenuScript = a_symmenu->menuscript
    lc_MnuPrompt  = a_symmenu->menuprompt
    ll_detlsmry   = a_symmenu->detlsmry
    lc_Applid     = a_symmenu->applid
    lc_CompID     = gc_CompiD
  ELSE
    ll_Return = .f.
    lc_ErrMsg = "Invalid MenuID"
  ENDIF

  *-- Close the table if opened here
  IF ln_OpnSymmenu = 2 AND go_SQL.m_IsUsed("a_symmenu")
    go_SQL.cmpA_Symmenu.m_CloseTable()
  ENDIF
  
  *-- Veryfy application
  IF ll_Return AND go_Pro.sc_Applid <> lc_Applid
    ll_Return = .f.
    lc_ErrMsg = "Cannot execute a menu option of another application." + Cc_oseol +;
                "Only '" + go_Pro.sc_Applid + "' menu options allowed. "
  ENDIF

ENDIF

IF ll_Return

  = WASMOUSE(.f.)

  lc_Descrip = d_retap(IIF(lc_ApplId = "SM", "SY", lc_ApplId), 1)

  *-- Reset the global object
  lo_GlobalsRef = go_Globals.m_GetObject(lc_applid, gc_compid)

  *-- Do not release variables if the application to be loaded is SM
  IF NOT INLIST(lc_applid, "SM", "SY") AND NOT EMPTY(gc_compid)

    lc_VarList = lo_GlobalsRef.m_GetVariables()

    *-- Release, Re-declare and initialize variables from global object
    RELEASE &lc_VarList.
    PUBLIC &lc_VarList.
    STORE SPACE(0) TO &lc_varlist.

    lo_GlobalsRef.m_SetAsVariables()
  ENDIF

  *-- Execute the script associated with the node
  lc_MenuScript = "#include helpid.h " + gc_OsEol + ;
                  "#include global.h " + gc_OsEol + lc_MenuScript

  *-- Get a filename for the script to be executed
  lc_PrgFileName = FORCEEXT(gc_idrvtmp + SYS(3), "PRG")
  DO WHILE FILE(lc_PrgFileName)
    lc_PrgFileName = FORCEEXT(gc_idrvtmp + SYS(3), "PRG")
  ENDDO

  *-- Store the menu script to the prg file
  = STRTOFILE(lc_MenuScript, lc_PrgFileName)

  *-- Compile the program
  COMPILE (lc_PrgFileName)

  *-- Execute the menu script in error
  *-- exception handler
  TRY
    *-- Execute the program file just created
    DO (lc_PrgFileName)

  CATCH TO lo_Exception

    *-- Set text for dialog message
    lc_ErrMsg = "An error occured while executing the menu script." + Cc_Oseol + ;
                Cc_Oseol + ;
                "Error " + LTRIM(STR(lo_Exception.errorno, 6, 0)) + ": " + ;
                lo_Exception.message + Cc_oseol + ;
                "Line number: " + LTRIM(STR(lo_Exception.lineno - 2, 5, 0)) + ;
                Cc_Oseol

    *-- If there is code line causing error is available
    lc_ErrorCode = lo_Exception.LineContents
    ll_Return = .f.

    IF NOT EMPTY(lc_ErrorCode)
      lc_ErrMsg = lc_ErrMsg + "Program code causing error:" + ;
                  Cc_oseol + ALLTRIM(lc_ErrorCode)
    ENDIF

  FINALLY
    *-- Erase the program file just created
    IF FILE(lc_PrgFileName)
      ERASE (lc_PrgFileName)
    ENDIF

    IF NOT go_Pro.sl_ShowMenu      
      *-- Clear menu
      DO l_ClearMenu

    ENDIF

  ENDTRY

ENDIF

IF NOT ll_return
  *-- Show up the error message
  = g_getdlg(lc_ErrMsg, 3, 1, "OK", "", "", "", "ProRunMenu")
ELSE
  *-- Activate the screen
  ACTIVATE SCREEN
ENDIF

RETURN

*---------------------------------------------------------------------------
*- Method      : l_ClearMenu
*---------------------------------------------------------------------------
*- Description : Remove the current application menu pads
*---------------------------------------------------------------------------
PROCEDURE l_ClearMenu

LPARAMETERS pl_EraseFile

  LOCAL lc_UserMpr, ;
        lc_RelMpr, ;
        lc_Temp

  *-- Remove the menu pads defined for the currently loaded
  *-- application before generating the new menu definition code
  lc_UserMpr = go_Cop.sc_MenuFile

  IF NOT EMPTY(lc_UserMpr)
    *-- Get the file name of the pads releasing MPR
    lc_RelMpr  = STRTRAN(lc_UserMpr, ".MPR", "RL.MPR")

    IF FILE(lc_RelMpr)
      *-- Compile the pads releasing MPR before executing it
      lc_temp = lc_RelMpr
      lc_temp = STRTRAN(UPPER(lc_temp), "." + JUSTEXT(lc_temp), ".MPX")
      DO &lc_temp.

      *-- set sysmen
      SET SYSMENU AUTOMATIC 
      ACTIVATE SCREEN 
    ENDIF

  ENDIF  && NOT EMPTY(lc_UserMpr)

RETURN
*------------------------------------------------------------------------------
*- End Procedure...: l_Clearmenu
*------------------------------------------------------------------------------
