*-------------------------------------------------------------------------------
*- Synopsis...: This program generates data dictionary changes between 2 builds
*-              of Pro Series.
*-              It gives:
*-                1.. New fields added (sydfldsNew)
*-                2.. New tables added (sydtablNew)
*-                3.. New indexes added (sydindxNew)
*-                4.. A text file that contains field information 
*-                    changed (FieldChanges.Txt)
*-              All these files are copied to the pc_ChangeFolder (passed)
*-
*- Assumptions: 1. Assumes you are running the tool from the root folder of
*-                 the new Pro Series build and have sydtabl, sydflds & sydindx
*-                 VFP tables in that folder.
*-              2. Assumes you have a sub folder named tools that has the 
*-                 file dbfcmpre.prg
*-------------------------------------------------------------------------------
*- Parameters.: pc_OldProductFolder - The root folder of the old product build
*-                  This folder should have sydtabl, sydflds & sydindx
*-                  VFP tables of the old build in that folder.
*-              pc_ChangeFolder - This folder is used to create the files (listed above)
*-                   Folder is created if folder not there. Give "\" at end
*-                   Files are overwritten if those files are already there
*-------------------------------------------------------------------------------
*- Calls......: tools\dbfcmpre.prg
*-------------------------------------------------------------------------------
*- Returns....: <expL>, .t.
*-------------------------------------------------------------------------------
LPARAMETERS pc_OldProductFolder, ;
            pc_ChangeFolder

LOCAL lc_OldProductFolder, ;
      lc_ChangeFolder

IF EMPTY(pc_OldProductFolder)

  lc_OldProductFolder = GETDIR("\", "Old Build folder", "", 64 + 16384)
  
  IF EMPTY(lc_OldProductFolder)
    RETURN
  ENDIF

ELSE
  lc_OldProductFolder = pc_OldProductFolder
ENDIF

IF EMPTY(pc_ChangeFolder)

  lc_ChangeFolder = GETDIR("\", "Folder to create compare files", "", 64 + 16384)
  
  IF EMPTY(lc_ChangeFolder)
    RETURN
  ENDIF

ELSE
  lc_ChangeFolder = pc_ChangeFolder
ENDIF


IF NOT DIRECTORY(lc_ChangeFolder)
  MD (lc_ChangeFolder)
ENDIF


SELECT * from sydflds ;
  WHERE tablid+fldsid NOT IN (select tablid+fldsid from (lc_OldProductFolder + "sydflds")) ;
  INTO TABLE (lc_ChangeFolder + "sydfldsNew")

SELECT * from sydtabl ;
  WHERE tablid NOT IN (select tablid from (lc_OldProductFolder + "sydtabl")) ;
  INTO TABLE (lc_ChangeFolder + "sydtablNew")

SELECT * from sydindx ;
  WHERE tablid+indxid NOT IN (select tablid+indxid from (lc_OldProductFolder + "sydindx")) ;
  INTO TABLE (lc_ChangeFolder + "sydindxNew")

CLOSE ALL

SELECT 0
USE (lc_OldProductFolder + "sydflds") ALIAS sydfldsOld
SET ORDER TO TABLID1   && TABLID+FLDSID

SELECT 0
USE sydflds ALIAS sydfldsNew
SET ORDER TO TABLID1   && TABLID+FLDSID
SET RELATION TO tablid+fldsid INTO sydfldsOld

SET FILTER TO NOT EOF("sydfldsold")
DO tools\dbfcmpre WITH "sydfldsNew", "sydfldsOld", ;
  "Field Changes", ;
  .t., ;
  lc_ChangeFolder + "FieldChanges.Txt", ;
  "tablid + ' ' + fldsid", ;
  "fldno", ;
  .f., ;
  .t.

= MESSAGEBOX( "Created data dictionary change files in " + lc_ChangeFolder + ".")

RETURN
