*------------------------------------------------------------------------------
*- Version....: Sage Pro ERP 7.50.00
*- File Name..: $Workfile: download.PRG $
*- VCS Level..: $Revision: 1 $
*- Last Update: $Date: 12/21/06 12:25p $
*------------------------------------------------------------------------------
*- Copyright (C) 2008 Sage Accpac International, Inc.  All Rights Reserved.
*------------------------------------------------------------------------------
*- App ID.....: SY
*- App Name...: Tools
*------------------------------------------------------------------------------
*- Synopsis...: Downloads a SQL server/DB2 table to a VFP table.
*-
*-              NOTE: You must have a valid go_Sql object before running the tool
*------------------------------------------------------------------------------
*- Parameters.: pc_TableToDownload, Pass the table name (w path and w/o extension)
*-              pc_Compid, Pass this if the table is not a system table.
*-              pc_DbfTable, Pass the name of the VFP table to download to.
*-                           Pass this with appropriate path name.
*-                           If the file is not there it will crate a new VFP table.
*-                           If the File is there it will ZAP and then append
*-                           contents of the SQL table.
*-              pl_Silent, [Optional] Set to .t. to avoid warnings. 
*-                         Will still put up dialog for errors.
*------------------------------------------------------------------------------
*- Called By..: Command Window
*------------------------------------------------------------------------------
LPARAMETERS pc_TableToDownload, ;
            pc_Compid, ;
            pc_DbfTable, ;
            pl_Silent

#include global.h
#include events.h

LOCAL ll_Return, ;
      lc_DbfTable, ;
      lc_SqlTable, ;
      lc_SqlDatabase, ;
      lc_SqlSelect, ;
      lc_Notify

PRIVATE lc_Compid

STORE Cc_Null TO lc_Compid, ;
                 lc_DbfTable, ;
                 lc_SqlTable, ;
                 lc_SqlDatabase, ;
                 lc_SqlSelect, ;
                 lc_Notify


#IF 0
LOCAL go_Sql AS sbtmgrsql OF "sbtsql.vcx" 
LOCAL lo_Table AS sbtcmpsql OF "sbtsql.vcx" 
#ENDIF

ll_Return = .t.

IF ll_Return AND TYPE("go_Sql.BaseClass") <> "C"
  = MESSAGEBOX("You must have go_Sql setup. Run DO tools\sqltest.")
  ll_Return = .f.
ENDIF

IF ll_Return AND ;
  go_Sql.sc_SqlTypeMain <> "S"

  = MESSAGEBOX("Your pro.ini is not Set for SQL/DB2. " + ;
     CHR(13) + "Fix this before running the tool")
  ll_Return = .f.
ENDIF

IF ll_Return AND ;
  EMPTY(pc_TableToDownload)

  = MESSAGEBOX("Please pass the name of the SQL/DB2 table to Download.")
  ll_Return = .f.
ENDIF

IF ll_Return AND ;
  UPPER(LEFT(pc_TableToDownLoad, 2)) <> "SY" AND ;
  EMPTY(pc_Compid)

  = MESSAGEBOX("Please pass the company id of the table to Download.")
  ll_Return = .f.
ENDIF  
  
IF ll_Return AND ;
  EMPTY(pc_DbfTable)

  = MESSAGEBOX("Please pass the VFP table to Download.")
  ll_Return = .f.
ENDIF

*-- Find full table name if SQL Server
IF ll_Return AND go_Sql.sc_Sqltype = "SS"
  lc_SqlTable = JUSTSTEM(ALLTRIM(pc_TableToDownload))
  
  IF UPPER(LEFT(lc_SqlTable, 2)) = "SY"
    *-- Is a system table.
    lc_SqlTable = go_Sql.sc_Sysdbname + lc_SqlTable
  ELSE
  
    IF NOT EMPTY(pc_Compid)
      *-- User has specified a company id.
      lc_Compid = pc_Compid
    ELSE
      lc_Compid = RIGHT(lc_SqlTable, 2)
    ENDIF
    
    TEXT TO lc_SqlSelect TEXTMERGE NOSHOW
      SELECT dbname FROM <<go_Sql.sc_sysdbname>>syccomp AS a_syccomp
        WHERE a_syccomp->compid = ?lc_compid
    ENDTEXT
      
    go_Sql.m_SqlSelect(STRTRAN(lc_SqlSelect, Cc_OsEol, ""),"CURSOR","ac_syccomp")
    
    IF go_Sql.cmpac_Syccomp.m_Reccount() > 0
      *-- Add the database name for the table and remove company #.
      lc_SqlTable = ac_syccomp->dbname + ".." + LEFT(lc_SqlTable, LEN(lc_SqlTable) - 2)
    ELSE
      = MESSAGEBOX("Company " + lc_Compid + " not found in backend syccomp.")
      ll_Return = .f.
    ENDIF

  ENDIF

ENDIF ll_Return AND go_Sql.sc_Sqltype = "SS"

*-- Find full table name if DB2
IF ll_Return AND go_Sql.sc_Sqltype = "SD"
  lc_SqlTable = JUSTSTEM(ALLTRIM(pc_TableToDownload))
  
  IF UPPER(LEFT(lc_SqlTable, 2)) <> "SY"
    *-- Is a company table.
  
    IF NOT EMPTY(pc_Compid)
      *-- User has specified a company id.
      lc_Compid = pc_Compid
    ELSE
      lc_Compid = RIGHT(lc_SqlTable, 2)
    ENDIF
    
    lc_SqlTable = LEFT(lc_SqlTable, LEN(lc_SqlTable) - 2) + lc_Compid
  ENDIF

ENDIF ll_Return AND go_Sql.sc_Sqltype = "SD"

IF ll_Return AND ;
  NOT go_Sql.m_IstableFound(lc_SqlTable, "S")
  = MESSAGEBOX("Table not found in backend " + ;
    lc_SqlTable + ".")
  ll_Return = .f.
ENDIF

IF ll_Return
  lc_DbfTable = DEFAULTEXT(pc_DbfTable, "DBF")
ENDIF

IF ll_Return AND ;
  NOT pl_Silent

  *-- Warn user before proceeding.
  IF FILE(lc_DbfTable)
    ll_Return = MESSAGEBOX("Want to copy contents of " + ;
      lc_SqlTable + " to " + ;
      lc_DbfTable +  "?", 4+32) = 6
  ELSE
    ll_Return = MESSAGEBOX("Want to create " + ;
      lc_DbfTable + " from " + ;
      lc_SqlTable + "?", 4+32) = 6
  ENDIF

ENDIF

IF ll_Return
  *-- All ok

  go_Sql.m_CloseTableAll()

  go_Sql.m_OpenTable("a_SqlTable", lc_SqlTable, .t.) 

  lo_Table = go_Sql.cmpA_SqlTable

  lc_Notify = SET("Notify")
  SET TALK ON
  
  SET NOTIFY ON
  
  IF FILE(lc_DbfTable)
    *-- Open Dbf Table
    go_Sql.m_Opentable("a_DbfTable", lc_DbfTable, .t.)
    lo_Table = go_Sql.cmpA_DbfTable

    *-- Remove old contents
    lo_Table.m_Zap()
  
    *-- Append from SQL table
    lo_Table.m_AppendFrom(lc_SqlTable)

    lo_Table.m_CloseTable()

  ELSE
    lo_Table = go_Sql.cmpA_SqlTable

    *-- Copy SQL table to VFP table
    go_Sql.cmpA_SqlTable.m_CopyTo(lc_DbfTable, "", "F")
  ENDIF
  
  go_Sql.cmpA_SqlTable.m_Close()
    

  SET NOTIFY &lc_Notify.
  SET TALK OFF
  
  IF NOT pl_Silent
    WAIT WINDOW "Download done to " + lc_DbfTable
  ENDIF

ENDIF

RETURN ll_Return
