*------------------------------------------------------------------------------
*- Version....: Sage Pro ERP 7.50.00
*- File Name..: $Workfile: resvword.PRG $
*- VCS Level..: $Revision: 1 $
*- Last Update: $Date: 12/21/06 12:25p $
*------------------------------------------------------------------------------
*- Copyright (C) 2008 Sage Accpac International, Inc.  All Rights Reserved.
*------------------------------------------------------------------------------
*- App ID.....: TOOLS
*- App Name...: Development tools
*------------------------------------------------------------------------------
*- Synopsis...: This utility reports custom field names that are not allowed 
*-              by SQL
*- 
*-              It assumes that your SydFlds has definitions for all the custom 
*-              fields. 
*-              If uses the ResvWord.Dbf for the reserved word field list in SQL
*------------------------------------------------------------------------------
*- Called By..: Command prompt or other tool
*------------------------------------------------------------------------------
#define Cc_OSEol      CHR(13) + CHR(10)

LOCAL ll_cont, ;
      lc_Text, ;
      lc_ProDir, ;
      lc_ToolsDir
        
  ll_cont = .t.
  lc_Text = ""
  lc_ProDir = "c:\Pro65\"
  lc_ToolsDir = ADDBS(FULLPATH("")) + "Tools\"
  SET DELETED ON

  *-- Check if the required tables are present
  DO CASE
    CASE NOT FILE(lc_ToolsDir + "ResvWord.Dbf")
      = MESSAGEBOX("Could not locate ResvWord.Dbf in the folder " + ;
                   lc_ToolsDir + ".", 16)
      ll_cont = .f.
    CASE NOT FILE(lc_ToolsDir + "SySqlCv.Dbf")
      = MESSAGEBOX("Could not locate SySqlCv.Dbf in the folder " + ;
                   lc_ToolsDir + ".", 16)
      ll_cont = .f.
    
    OTHERWISE 
      *-- Open tables used by this tools
      IF USED("a_ResvWord")
        USE IN a_ResvWord
      ENDIF

      IF USED("a_SySqlCv")
        USE IN a_SySqlCv
      ENDIF

      USE (lc_ToolsDir + "ResvWord.Dbf") ALIAS a_ResvWord IN 0
      USE (lc_ToolsDir + "SySqlCv.Dbf") ALIAS a_SySqlCv IN 0
      
      MESSAGEBOX("This tool searches your Pro Series data dictionary for custom fields that"+ ;
                 Cc_OSEol + ;
                 "conflicts with SQL Server reserved words. Please select the Pro Series " + ;
                 Cc_OSEol + ;
                 "folder that you are upgrading to SQL 2000. ")
      lc_ProDir = GETDIR(lc_ProDir, "Select Pro Series folder", "Select Pro Series folder")
  ENDCASE 

  *-- Check if pro directory is valid
  DO CASE
    CASE NOT ll_cont
      *-- Cancelled operation
    CASE EMPTY(lc_ProDir) OR NOT ll_cont
      *-- Cancelled operation
      ll_cont = .f.
    CASE NOT FILE(ADDBS(lc_ProDir) + "SydFlds.dbf")
      = MESSAGEBOX("Could not locate SydFlds.dbf in the folder " + ;
                   lc_ProDir + ".", 16)
      ll_cont = .f.
    OTHERWISE 
      *-- Open SydFlds
      IF USED("a_SydFlds")
        USE IN a_SydFlds
      ENDIF
        
      USE (lc_ProDir + "SydFlds.Dbf") ALIAS a_SydFlds IN 0
      ll_cont = .t.
  ENDCASE 

  *-- Begin Process 
  IF ll_cont
    *-- copy dictionary table
    SELECT tablid, fldsid, fldno FROM a_SydFlds INTO CURSOR ac_Flds READWRITE 
    INDEX ON tablid +  fldsid TAG tablid1
    
    *-- Rename existing old reserved fields to new names
    SELECT a_SySqlCv
    SCAN
      SELECT ac_Flds
      SEEK a_SySqlCv->Tablid + a_SySqlCv->OldFldsId

      IF FOUND()
        REPLACE fldsid WITH a_SySqlCv->NewFldsId
      ENDIF 
       
    ENDSCAN
    
    *-- Find if ac_Flds has any reserved words
    SELECT ac_Flds.* FROM ac_Flds ;
       INNER JOIN a_ResvWord ON ac_Flds.Fldsid = a_ResvWord.ResvWord ;
    WHERE NOT INLIST(tablid, 'JCAPTRAN', 'JCJCTRAN') ;
    INTO CURSOR ac_Flds1
    
    IF RECCOUNT("ac_Flds1") > 0 AND ;
       MESSAGEBOX("Detected custom field names in your data dictionary that conflicts with " + ;
                 Cc_OSEol + ;
                 "the SQL Server reserved words. Tables with field names using SQL " + ;
                 Cc_OSEol + ;
                 "reserved words cannot be converted to SQL 2000. " + ;
                 Cc_OSEol + ;
                 Cc_OSEol + ;
                 "Do you want to list?", 4 ) = 6
      BROWSE NOEDIT
    ELSE
       MESSAGEBOX("None of the custom field names in your data dictionary conflicts with " + ;
                  Cc_OSEol + ;
                  "the SQL Server reserved words." )
    ENDIF
    
  ENDIF 

  IF USED("a_SydFlds")
    USE IN a_SydFlds
  ENDIF
    
  IF USED("a_ResvWord")
    USE IN a_ResvWord
  ENDIF

  IF USED("a_SySqlCv")
    USE IN a_SySqlCv
  ENDIF

  IF USED("ac_Flds")
    USE IN ac_Flds 
  ENDIF
  
  IF USED("ac_Flds1")
    USE IN ac_Flds1
  ENDIF

RETURN
  
